@@ -425,6 +425,7 @@ class Struct(ScaleType):
     def process(self):
 
         result = {}
+
         for key, data_type in self.type_mapping:
             if data_type is None:
                 data_type = 'Null'
@@ -1145,6 +1146,10 @@ class GenericCall(ScaleType):
         }
 
     def process_encode(self, value):
+
+        if type(value) is not dict:
+            raise TypeError("value must be of type dict to encode a GenericCall")
+
         # Check requirements
         if 'call_index' in value:
             self.call_index = value['call_index']
@@ -1187,15 +1192,17 @@ class OpaqueCall(Bytes):
         return super().process_encode(str(call_obj.encode(value)))
 
     def process(self):
-        super().process()
+        value = super().process()
+        try:
+            call_obj = self.get_decoder_class(
+                type_string='Call',
+                data=ScaleBytes('0x{}'.format(self.raw_value)),
+                metadata=self.metadata
+            )
 
-        call_obj = self.get_decoder_class(
-            type_string='Call',
-            data=ScaleBytes('0x{}'.format(self.raw_value)),
-            metadata=self.metadata
-        )
-
-        return call_obj.process()
+            return call_obj.process()
+        except:
+            return value
 
 
 class MultiAccountId(GenericAccountId):
